# 1T support files

In this subdirectory, we store XENON1T related files / scripts that are only used for xenon1t.

This folder is only marginally useful, you probably want to go of using a straxen version pre-v1.0.0 where we still were
actively checking and using the 1T chain.
